@@ -4,6 +4,10 @@ import os
 import yaml
 from discord.ext import commands
 
+from poglink.config import BOOLEAN_VALUES, LIST_VALUES
+from poglink.error import ConfigReadError
+from poglink.utils import parse_bool, parse_list
+
 logger = logging.getLogger(__name__)
 
 
@@ -15,9 +19,10 @@ class BotConfig:
         bans_channel_id=None,
         polling_delay=None,
         allowed_roles=None,
-        rates_url=None,
+        rates_urls=None,
         # bans_url=None,
         data_dir=None,
+        publish_on_startup=None,
         **kwargs,
     ) -> None:
         self.token = token
@@ -25,13 +30,33 @@ class BotConfig:
         self.bans_channel_id = bans_channel_id
         self.polling_delay = polling_delay
         self.allowed_roles = allowed_roles
-        self.rates_url = rates_url
+        self.rates_urls = rates_urls
         # self.bans_url = bans_url
         self.data_dir = data_dir
+        self.publish_on_startup = publish_on_startup
+
+        # handle special cases for boolean values
+        for param in BOOLEAN_VALUES:
+            if not isinstance(getattr(self, param), bool):
+                setattr(self, param, parse_bool(getattr(self, param)))
+
+        # handle special cases for list parsing
+        for param in LIST_VALUES:
+            if isinstance(getattr(self, param), str):
+                setattr(self, param, parse_list(getattr(self, param)))
+            elif isinstance(getattr(self, param), list):
+                pass
+            else:
+                logger.warning(
+                    f"Incorrect variable format for {param}; should be comma separated list. Actual value: {getattr(self, param)}"
+                )
 
         for k, v in kwargs.items():
             setattr(self, k, v)
 
+    def __eq__(self, __o: object) -> bool:
+        return self.__dict__ == __o.__dict__
+
     @classmethod
     def from_dict(cls, d):
         return cls(**d)
@@ -63,16 +88,22 @@ class BotConfig:
                 logger.error(
                     f"Could not read config file at specified location: {config_path}"
                 )
-                raise Exception(f"Could not read file at {fullpath}")
+                raise ConfigReadError(f"Could not read file at {fullpath}")
         else:
             logger.error(f"File does not exist at location: {fullpath}")
             raise FileNotFoundError("File does not exist at location")
 
         return cls.from_dict(config_from_file)
 
+    def __repr__(self):
+        return f"BotConfig<rates_channel_id={self.rates_channel_id}, bans_channel_id={self.bans_channel_id}, polling_delay={self.polling_delay}>"
+
 
 class ConfigurableBot(commands.Bot):
     def __init__(self, command_prefix, config_dict, **kwargs):
         self.config = BotConfig.from_dict(config_dict)
 
         super().__init__(command_prefix, **kwargs)
+
+    def __repr__(self):
+        return f"ConfigurableBot<config={self.config}>"
